@@ -17,9 +17,9 @@
 
 import logging
 
-from osc_lib.command import command
 from osc_lib import utils
 
+from openstackclient import command
 from openstackclient.i18n import _
 
 LOG = logging.getLogger(__name__)
