@@ -21,10 +21,10 @@ import sys
 import typing as ty
 
 from openstack import exceptions as sdk_exceptions
-from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
 
+from openstackclient import command
 from openstackclient.i18n import _
 from openstackclient.network import common
 
@@ -272,7 +272,10 @@ class ListQuota(command.Lister):
                 sdk_exceptions.NotFoundException,
             ) as exc:
                 # Project not found, move on to next one
-                LOG.warning(f"Project {project_id} not found: {exc}")
+                LOG.warning(
+                    'Project %(project_id)s not found: %(exc)s',
+                    {'project_id': project_id, 'exc': exc},
+                )
                 continue
 
             project_result = _xform_get_quota(
@@ -334,7 +337,10 @@ class ListQuota(command.Lister):
                 sdk_exceptions.NotFoundException,
             ) as exc:
                 # Project not found, move on to next one
-                LOG.warning(f"Project {project_id} not found: {exc}")
+                LOG.warning(
+                    'Project %(project_id)s not found: %(exc)s',
+                    {'project_id': project_id, 'exc': exc},
+                )
                 continue
 
             project_result = _xform_get_quota(
@@ -389,7 +395,10 @@ class ListQuota(command.Lister):
                 sdk_exceptions.ForbiddenException,
             ) as exc:
                 # Project not found, move on to next one
-                LOG.warning(f"Project {project_id} not found: {exc}")
+                LOG.warning(
+                    'Project %(project_id)s not found: %(exc)s',
+                    {'project_id': project_id, 'exc': exc},
+                )
                 continue
 
             project_result = _xform_get_quota(
@@ -746,21 +755,32 @@ and ``server-group-members`` output for a given quota class."""
         # values if the project or class does not exist. This is expected
         # behavior. However, we have already checked for the presence of the
         # project above so it shouldn't be an issue.
-        if parsed_args.service in {'all', 'compute'}:
+        if parsed_args.service == 'compute' or (
+            parsed_args.service == 'all'
+            and self.app.client_manager.is_compute_endpoint_enabled()
+        ):
             compute_quota_info = get_compute_quotas(
                 self.app,
                 project,
                 detail=parsed_args.usage,
                 default=parsed_args.default,
             )
-        if parsed_args.service in {'all', 'volume'}:
+
+        if parsed_args.service == 'volume' or (
+            parsed_args.service == 'all'
+            and self.app.client_manager.is_volume_endpoint_enabled()
+        ):
             volume_quota_info = get_volume_quotas(
                 self.app,
                 project,
                 detail=parsed_args.usage,
                 default=parsed_args.default,
             )
-        if parsed_args.service in {'all', 'network'}:
+
+        if parsed_args.service == 'network' or (
+            parsed_args.service == 'all'
+            and self.app.client_manager.is_network_endpoint_enabled()
+        ):
             network_quota_info = get_network_quotas(
                 self.app,
                 project,
@@ -786,20 +806,25 @@ and ``server-group-members`` output for a given quota class."""
         info.update(volume_quota_info)
         info.update(network_quota_info)
 
-        # Map the internal quota names to the external ones
-        # COMPUTE_QUOTAS and NETWORK_QUOTAS share floating-ips,
-        # secgroup-rules and secgroups as dict value, so when
-        # neutron is enabled, quotas of these three resources
-        # in nova will be replaced by neutron's.
-        for k, v in itertools.chain(
-            COMPUTE_QUOTAS.items(),
-            NOVA_NETWORK_QUOTAS.items(),
-            VOLUME_QUOTAS.items(),
-            NETWORK_QUOTAS.items(),
-        ):
-            if not k == v and info.get(k) is not None:
-                info[v] = info[k]
-                info.pop(k)
+        def _normalize_names(section: dict) -> None:
+            # Map the internal quota names to the external ones
+            # COMPUTE_QUOTAS and NETWORK_QUOTAS share floating-ips,
+            # secgroup-rules and secgroups as dict value, so when
+            # neutron is enabled, quotas of these three resources
+            # in nova will be replaced by neutron's.
+            for k, v in itertools.chain(
+                COMPUTE_QUOTAS.items(),
+                NOVA_NETWORK_QUOTAS.items(),
+                VOLUME_QUOTAS.items(),
+                NETWORK_QUOTAS.items(),
+            ):
+                if not k == v and section.get(k) is not None:
+                    section[v] = section.pop(k)
+
+        _normalize_names(info)
+        if parsed_args.usage:
+            _normalize_names(info["reservation"])
+            _normalize_names(info["usage"])
 
         # Remove the 'id' field since it's not very useful
         if 'id' in info:
@@ -906,12 +931,18 @@ class DeleteQuota(command.Command):
         )
 
         # compute quotas
-        if parsed_args.service in {'all', 'compute'}:
+        if parsed_args.service == 'compute' or (
+            parsed_args.service == 'all'
+            and self.app.client_manager.is_compute_endpoint_enabled()
+        ):
             compute_client = self.app.client_manager.compute
             compute_client.revert_quota_set(project.id)
 
         # volume quotas
-        if parsed_args.service in {'all', 'volume'}:
+        if parsed_args.service == 'volume' or (
+            parsed_args.service == 'all'
+            and self.app.client_manager.is_volume_endpoint_enabled()
+        ):
             volume_client = self.app.client_manager.sdk_connection.volume
             volume_client.revert_quota_set(project.id)
 
