@@ -15,100 +15,154 @@
 
 """Keypair action implementations"""
 
-import io
+import collections
 import logging
 import os
-import sys
 
+from cryptography.hazmat.primitives.asymmetric import ed25519
+from cryptography.hazmat.primitives import serialization
 from openstack import utils as sdk_utils
-from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
 
+from openstackclient import command
+from openstackclient.common import pagination
 from openstackclient.i18n import _
 from openstackclient.identity import common as identity_common
 
 
 LOG = logging.getLogger(__name__)
+Keypair = collections.namedtuple('Keypair', 'private_key public_key')
+
+
+def _generate_keypair():
+    """Generate a Ed25519 keypair in OpenSSH format.
+
+    :returns: A `Keypair` named tuple with the generated private and public
+    keys.
+    """
+    key = ed25519.Ed25519PrivateKey.generate()
+    private_key = key.private_bytes(
+        serialization.Encoding.PEM,
+        serialization.PrivateFormat.OpenSSH,
+        serialization.NoEncryption(),
+    ).decode()
+    public_key = (
+        key.public_key()
+        .public_bytes(
+            serialization.Encoding.OpenSSH, serialization.PublicFormat.OpenSSH
+        )
+        .decode()
+    )
+
+    return Keypair(private_key, public_key)
 
 
 def _get_keypair_columns(item, hide_pub_key=False, hide_priv_key=False):
     # To maintain backwards compatibility we need to rename sdk props to
     # whatever OSC was using before
-    column_map = {}
     hidden_columns = ['links', 'location']
     if hide_pub_key:
         hidden_columns.append('public_key')
     if hide_priv_key:
         hidden_columns.append('private_key')
     return utils.get_osc_show_columns_for_sdk_resource(
-        item, column_map, hidden_columns)
+        item, {}, hidden_columns
+    )
 
 
 class CreateKeypair(command.ShowOne):
     _description = _("Create new public or private key for server ssh access")
 
     def get_parser(self, prog_name):
-        parser = super(CreateKeypair, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
-            'name',
-            metavar='<name>',
-            help=_("New public or private key name")
+            'name', metavar='<name>', help=_("New public or private key name")
         )
         key_group = parser.add_mutually_exclusive_group()
         key_group.add_argument(
             '--public-key',
             metavar='<file>',
-            help=_("Filename for public key to add. If not used, "
-                   "creates a private key.")
+            help=_(
+                "Filename for public key to add. "
+                "If not used, generates a private key in ssh-ed25519 format. "
+                "To generate keys in other formats, including the legacy "
+                "ssh-rsa format, you must use an external tool such as "
+                "ssh-keygen and specify this argument."
+            ),
         )
         key_group.add_argument(
             '--private-key',
             metavar='<file>',
-            help=_("Filename for private key to save. If not used, "
-                   "print private key in console.")
+            help=_(
+                "Filename for private key to save. "
+                "If not used, print private key in console."
+            ),
         )
         parser.add_argument(
             '--type',
             metavar='<type>',
             choices=['ssh', 'x509'],
             help=_(
-                "Keypair type. Can be ssh or x509. "
-                "(Supported by API versions '2.2' - '2.latest')"
+                'Keypair type '
+                '(supported by --os-compute-api-version 2.2 or above)'
             ),
         )
         parser.add_argument(
             '--user',
             metavar='<user>',
             help=_(
-                'The owner of the keypair. (admin only) (name or ID). '
-                'Requires ``--os-compute-api-version`` 2.10 or greater.'
+                'The owner of the keypair (admin only) (name or ID) '
+                '(supported by --os-compute-api-version 2.10 or above)'
             ),
         )
         identity_common.add_user_domain_option_to_parser(parser)
         return parser
 
     def take_action(self, parsed_args):
-        compute_client = self.app.client_manager.sdk_connection.compute
+        compute_client = self.app.client_manager.compute
         identity_client = self.app.client_manager.identity
 
-        kwargs = {
-            'name': parsed_args.name
-        }
+        kwargs = {'name': parsed_args.name}
 
-        public_key = parsed_args.public_key
-        if public_key:
+        if parsed_args.public_key:
             try:
-                with io.open(os.path.expanduser(parsed_args.public_key)) as p:
+                with open(os.path.expanduser(parsed_args.public_key)) as p:
                     public_key = p.read()
-            except IOError as e:
+            except OSError as e:
                 msg = _("Key file %(public_key)s not found: %(exception)s")
                 raise exceptions.CommandError(
-                    msg % {"public_key": parsed_args.public_key,
-                           "exception": e}
+                    msg
+                    % {
+                        "public_key": parsed_args.public_key,
+                        "exception": e,
+                    }
                 )
 
             kwargs['public_key'] = public_key
+        else:
+            generated_keypair = _generate_keypair()
+            kwargs['public_key'] = generated_keypair.public_key
+
+            # If user have us a file, save private key into specified file
+            if parsed_args.private_key:
+                try:
+                    with open(
+                        os.path.expanduser(parsed_args.private_key), 'w+'
+                    ) as p:
+                        p.write(generated_keypair.private_key)
+                except OSError as e:
+                    msg = _(
+                        "Key file %(private_key)s can not be saved: "
+                        "%(exception)s"
+                    )
+                    raise exceptions.CommandError(
+                        msg
+                        % {
+                            "private_key": parsed_args.private_key,
+                            "exception": e,
+                        }
+                    )
 
         if parsed_args.type:
             if not sdk_utils.supports_microversion(compute_client, '2.2'):
@@ -136,32 +190,18 @@ class CreateKeypair(command.ShowOne):
 
         keypair = compute_client.create_keypair(**kwargs)
 
-        private_key = parsed_args.private_key
-        # Save private key into specified file
-        if private_key:
-            try:
-                with io.open(
-                    os.path.expanduser(parsed_args.private_key), 'w+'
-                ) as p:
-                    p.write(keypair.private_key)
-            except IOError as e:
-                msg = _("Key file %(private_key)s can not be saved: "
-                        "%(exception)s")
-                raise exceptions.CommandError(
-                    msg % {"private_key": parsed_args.private_key,
-                           "exception": e}
-                )
         # NOTE(dtroyer): how do we want to handle the display of the private
         #                key when it needs to be communicated back to the user
         #                For now, duplicate nova keypair-add command output
-        if public_key or private_key:
+        if parsed_args.public_key or parsed_args.private_key:
             display_columns, columns = _get_keypair_columns(
-                keypair, hide_pub_key=True, hide_priv_key=True)
+                keypair, hide_pub_key=True, hide_priv_key=True
+            )
             data = utils.get_item_properties(keypair, columns)
 
             return (display_columns, data)
         else:
-            sys.stdout.write(keypair.private_key)
+            self.app.stdout.write(generated_keypair.private_key)
             return ({}, {})
 
 
@@ -169,12 +209,12 @@ class DeleteKeypair(command.Command):
     _description = _("Delete public or private key(s)")
 
     def get_parser(self, prog_name):
-        parser = super(DeleteKeypair, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'name',
             metavar='<key>',
             nargs='+',
-            help=_("Name of key(s) to delete (name only)")
+            help=_("Name of key(s) to delete (name only)"),
         )
         parser.add_argument(
             '--user',
@@ -188,7 +228,7 @@ class DeleteKeypair(command.Command):
         return parser
 
     def take_action(self, parsed_args):
-        compute_client = self.app.client_manager.sdk_connection.compute
+        compute_client = self.app.client_manager.compute
         identity_client = self.app.client_manager.identity
 
         kwargs = {}
@@ -211,16 +251,21 @@ class DeleteKeypair(command.Command):
         for n in parsed_args.name:
             try:
                 compute_client.delete_keypair(
-                    n, **kwargs, ignore_missing=False)
+                    n, **kwargs, ignore_missing=False
+                )
             except Exception as e:
                 result += 1
-                LOG.error(_("Failed to delete key with name "
-                          "'%(name)s': %(e)s"), {'name': n, 'e': e})
+                LOG.error(
+                    _("Failed to delete key with name '%(name)s': %(e)s"),
+                    {'name': n, 'e': e},
+                )
 
         if result > 0:
             total = len(parsed_args.name)
-            msg = (_("%(result)s of %(total)s keys failed "
-                   "to delete.") % {'result': result, 'total': total})
+            msg = _("%(result)s of %(total)s keys failed to delete.") % {
+                'result': result,
+                'total': total,
+            }
             raise exceptions.CommandError(msg)
 
 
@@ -249,20 +294,13 @@ class ListKeypair(command.Lister):
             ),
         )
         identity_common.add_project_domain_option_to_parser(parser)
-        parser.add_argument(
-            '--marker',
-            help=_('The last keypair ID of the previous page'),
-        )
-        parser.add_argument(
-            '--limit',
-            type=int,
-            help=_('Maximum number of keypairs to display'),
-        )
+        pagination.add_marker_pagination_option_to_parser(parser)
         return parser
 
     def take_action(self, parsed_args):
-        compute_client = self.app.client_manager.sdk_connection.compute
+        compute_client = self.app.client_manager.compute
         identity_client = self.app.client_manager.identity
+        identity_sdk_client = self.app.client_manager.sdk_connection.identity
 
         kwargs = {}
 
@@ -298,9 +336,7 @@ class ListKeypair(command.Lister):
                 # NOTE(stephenfin): Because we're doing this client-side, we
                 # can't really rely on the marker, because we don't know what
                 # user the marker is associated with
-                msg = _(
-                    '--project is not compatible with --marker'
-                )
+                msg = _('--project is not compatible with --marker')
 
             # NOTE(stephenfin): This is done client side because nova doesn't
             # currently support doing so server-side. If this is slow, we can
@@ -310,11 +346,17 @@ class ListKeypair(command.Lister):
                 parsed_args.project,
                 parsed_args.project_domain,
             ).id
-            users = identity_client.users.list(tenant_id=project)
+            assignments = identity_sdk_client.role_assignments(
+                scope_project_id=project
+            )
+            user_ids = set()
+            for assignment in assignments:
+                if assignment.user:
+                    user_ids.add(assignment.user['id'])
 
             data = []
-            for user in users:
-                kwargs['user_id'] = user.id
+            for user_id in user_ids:
+                kwargs['user_id'] = user_id
                 data.extend(compute_client.keypairs(**kwargs))
         elif parsed_args.user:
             if not sdk_utils.supports_microversion(compute_client, '2.10'):
@@ -335,13 +377,10 @@ class ListKeypair(command.Lister):
         else:
             data = compute_client.keypairs(**kwargs)
 
-        columns = (
-            "Name",
-            "Fingerprint"
-        )
+        columns: tuple[str, ...] = ("Name", "Fingerprint")
 
         if sdk_utils.supports_microversion(compute_client, '2.2'):
-            columns += ("Type", )
+            columns += ("Type",)
 
         return (
             columns,
@@ -353,17 +392,17 @@ class ShowKeypair(command.ShowOne):
     _description = _("Display key details")
 
     def get_parser(self, prog_name):
-        parser = super(ShowKeypair, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'name',
             metavar='<key>',
-            help=_("Public or private key to display (name only)")
+            help=_("Public or private key to display (name only)"),
         )
         parser.add_argument(
             '--public-key',
             action='store_true',
             default=False,
-            help=_("Show only bare public key paired with the generated key")
+            help=_("Show only bare public key paired with the generated key"),
         )
         parser.add_argument(
             '--user',
@@ -377,7 +416,7 @@ class ShowKeypair(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        compute_client = self.app.client_manager.sdk_connection.compute
+        compute_client = self.app.client_manager.compute
         identity_client = self.app.client_manager.identity
 
         kwargs = {}
@@ -397,13 +436,15 @@ class ShowKeypair(command.ShowOne):
             ).id
 
         keypair = compute_client.find_keypair(
-            parsed_args.name, **kwargs, ignore_missing=False)
+            parsed_args.name, **kwargs, ignore_missing=False
+        )
 
         if not parsed_args.public_key:
             display_columns, columns = _get_keypair_columns(
-                keypair, hide_pub_key=True)
+                keypair, hide_pub_key=True
+            )
             data = utils.get_item_properties(keypair, columns)
             return (display_columns, data)
         else:
-            sys.stdout.write(keypair.public_key)
+            self.app.stdout.write(keypair.public_key)
             return ({}, {})
