@@ -16,33 +16,46 @@
 
 import logging
 
-from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
 
+from openstackclient import command
 from openstackclient.i18n import _
 
 
 LOG = logging.getLogger(__name__)
 
 
+def _format_protocol(protocol):
+    columns = ('name', 'idp_id', 'mapping_id')
+    column_headers = ('id', 'identity_provider', 'mapping')
+    return (
+        column_headers,
+        utils.get_item_properties(protocol, columns),
+    )
+
+
 class CreateProtocol(command.ShowOne):
     _description = _("Create new federation protocol")
 
     def get_parser(self, prog_name):
-        parser = super(CreateProtocol, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'federation_protocol',
             metavar='<name>',
-            help=_('New federation protocol name (must be unique '
-                   'per identity provider)'),
+            help=_(
+                'New federation protocol name (must be unique '
+                'per identity provider)'
+            ),
         )
         parser.add_argument(
             '--identity-provider',
             metavar='<identity-provider>',
             required=True,
-            help=_('Identity provider that will support the new federation '
-                   ' protocol (name or ID) (required)'),
+            help=_(
+                'Identity provider that will support the new federation '
+                ' protocol (name or ID) (required)'
+            ),
         )
         parser.add_argument(
             '--mapping',
@@ -54,27 +67,22 @@ class CreateProtocol(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        identity_client = self.app.client_manager.identity
-        protocol = identity_client.federation.protocols.create(
-            protocol_id=parsed_args.federation_protocol,
-            identity_provider=parsed_args.identity_provider,
-            mapping=parsed_args.mapping)
-        info = dict(protocol._info)
-        # NOTE(marek-denis): Identity provider is not included in a response
-        # from Keystone, however it should be listed to the user. Add it
-        # manually to the output list, simply reusing value provided by the
-        # user.
-        info['identity_provider'] = parsed_args.identity_provider
-        info['mapping'] = info.pop('mapping_id')
-        info.pop('links', None)
-        return zip(*sorted(info.items()))
+        identity_client = self.app.client_manager.sdk_connection.identity
+
+        protocol = identity_client.create_federation_protocol(
+            name=parsed_args.federation_protocol,
+            idp_id=parsed_args.identity_provider,
+            mapping_id=parsed_args.mapping,
+        )
+
+        return _format_protocol(protocol)
 
 
 class DeleteProtocol(command.Command):
     _description = _("Delete federation protocol(s)")
 
     def get_parser(self, prog_name):
-        parser = super(DeleteProtocol, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'federation_protocol',
             metavar='<federation-protocol>',
@@ -85,29 +93,41 @@ class DeleteProtocol(command.Command):
             '--identity-provider',
             metavar='<identity-provider>',
             required=True,
-            help=_('Identity provider that supports <federation-protocol> '
-                   '(name or ID) (required)'),
+            help=_(
+                'Identity provider that supports <federation-protocol> '
+                '(name or ID) (required)'
+            ),
         )
 
         return parser
 
     def take_action(self, parsed_args):
-        identity_client = self.app.client_manager.identity
+        identity_client = self.app.client_manager.sdk_connection.identity
+
         result = 0
         for i in parsed_args.federation_protocol:
             try:
-                identity_client.federation.protocols.delete(
-                    parsed_args.identity_provider, i)
+                identity_client.delete_federation_protocol(
+                    idp_id=parsed_args.identity_provider,
+                    protocol=i,
+                    ignore_missing=False,
+                )
             except Exception as e:
                 result += 1
-                LOG.error(_("Failed to delete federation protocol "
-                          "with name or ID '%(protocol)s': %(e)s"),
-                          {'protocol': i, 'e': e})
+                LOG.error(
+                    _(
+                        "Failed to delete federation protocol "
+                        "with name or ID '%(protocol)s': %(e)s"
+                    ),
+                    {'protocol': i, 'e': e},
+                )
 
         if result > 0:
             total = len(parsed_args.federation_protocol)
-            msg = (_("%(result)s of %(total)s federation protocols failed"
-                   " to delete.") % {'result': result, 'total': total})
+            msg = _(
+                "%(result)s of %(total)s federation protocols failed"
+                " to delete."
+            ) % {'result': result, 'total': total}
             raise exceptions.CommandError(msg)
 
 
@@ -115,7 +135,7 @@ class ListProtocols(command.Lister):
     _description = _("List federation protocols")
 
     def get_parser(self, prog_name):
-        parser = super(ListProtocols, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             '--identity-provider',
             metavar='<identity-provider>',
@@ -126,14 +146,17 @@ class ListProtocols(command.Lister):
         return parser
 
     def take_action(self, parsed_args):
-        identity_client = self.app.client_manager.identity
+        identity_client = self.app.client_manager.sdk_connection.identity
 
-        protocols = identity_client.federation.protocols.list(
-            parsed_args.identity_provider)
+        protocols = identity_client.federation_protocols(
+            parsed_args.identity_provider
+        )
         columns = ('id', 'mapping')
         response_attributes = ('id', 'mapping_id')
-        items = [utils.get_item_properties(s, response_attributes)
-                 for s in protocols]
+        items = [
+            utils.get_item_properties(s, response_attributes)
+            for s in protocols
+        ]
         return (columns, items)
 
 
@@ -141,7 +164,7 @@ class SetProtocol(command.Command):
     _description = _("Set federation protocol properties")
 
     def get_parser(self, prog_name):
-        parser = super(SetProtocol, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'federation_protocol',
             metavar='<name>',
@@ -151,8 +174,10 @@ class SetProtocol(command.Command):
             '--identity-provider',
             metavar='<identity-provider>',
             required=True,
-            help=_('Identity provider that supports <federation-protocol> '
-                   '(name or ID) (required)'),
+            help=_(
+                'Identity provider that supports <federation-protocol> '
+                '(name or ID) (required)'
+            ),
         )
         parser.add_argument(
             '--mapping',
@@ -162,26 +187,23 @@ class SetProtocol(command.Command):
         return parser
 
     def take_action(self, parsed_args):
-        identity_client = self.app.client_manager.identity
+        identity_client = self.app.client_manager.sdk_connection.identity
 
-        protocol = identity_client.federation.protocols.update(
-            parsed_args.identity_provider, parsed_args.federation_protocol,
-            parsed_args.mapping)
-        info = dict(protocol._info)
-        # NOTE(marek-denis): Identity provider is not included in a response
-        # from Keystone, however it should be listed to the user. Add it
-        # manually to the output list, simply reusing value provided by the
-        # user.
-        info['identity_provider'] = parsed_args.identity_provider
-        info['mapping'] = info.pop('mapping_id')
-        return zip(*sorted(info.items()))
+        kwargs = {'idp_id': parsed_args.identity_provider}
+        if parsed_args.federation_protocol:
+            kwargs['name'] = parsed_args.federation_protocol
+        if parsed_args.mapping:
+            kwargs['mapping_id'] = parsed_args.mapping
+
+        protocol = identity_client.update_federation_protocol(**kwargs)
+        return _format_protocol(protocol)
 
 
 class ShowProtocol(command.ShowOne):
     _description = _("Display federation protocol details")
 
     def get_parser(self, prog_name):
-        parser = super(ShowProtocol, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'federation_protocol',
             metavar='<federation-protocol>',
@@ -191,17 +213,18 @@ class ShowProtocol(command.ShowOne):
             '--identity-provider',
             metavar='<identity-provider>',
             required=True,
-            help=_('Identity provider that supports <federation-protocol> '
-                   '(name or ID) (required)'),
+            help=_(
+                'Identity provider that supports <federation-protocol> '
+                '(name or ID) (required)'
+            ),
         )
         return parser
 
     def take_action(self, parsed_args):
-        identity_client = self.app.client_manager.identity
+        identity_client = self.app.client_manager.sdk_connection.identity
 
-        protocol = identity_client.federation.protocols.get(
-            parsed_args.identity_provider, parsed_args.federation_protocol)
-        info = dict(protocol._info)
-        info['mapping'] = info.pop('mapping_id')
-        info.pop('links', None)
-        return zip(*sorted(info.items()))
+        protocol = identity_client.get_federation_protocol(
+            idp_id=parsed_args.identity_provider,
+            protocol=parsed_args.federation_protocol,
+        )
+        return _format_protocol(protocol)
