@@ -17,31 +17,28 @@
 
 import argparse
 from base64 import b64encode
+import copy
 import logging
 import os
 import sys
+import typing as ty
+import urllib.parse
 
-from cinderclient import api_versions
 from openstack import exceptions as sdk_exceptions
 from openstack.image import image_signer
+from openstack import utils as sdk_utils
 from osc_lib.api import utils as api_utils
 from osc_lib.cli import format_columns
 from osc_lib.cli import parseractions
-from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
 
+from openstackclient import command
 from openstackclient.common import pagination
 from openstackclient.common import progressbar
 from openstackclient.i18n import _
 from openstackclient.identity import common as identity_common
 
-if os.name == "nt":
-    import msvcrt
-else:
-    msvcrt = None
-
-
 CONTAINER_CHOICES = ["ami", "ari", "aki", "bare", "docker", "ova", "ovf"]
 DEFAULT_CONTAINER_FORMAT = 'bare'
 DEFAULT_DISK_FORMAT = 'raw'
@@ -58,9 +55,21 @@ DISK_CHOICES = [
     "iso",
     "ploop",
 ]
+# A list of openstacksdk Image object attributes (values) that named
+# differently from actual properties stored by Glance (keys).
+IMAGE_ATTRIBUTES_CUSTOM_NAMES = {
+    'os_hidden': 'is_hidden',
+    'protected': 'is_protected',
+    'os_hash_algo': 'hash_algo',
+    'os_hash_value': 'hash_value',
+    'img_config_drive': 'needs_config_drive',
+    'os_secure_boot': 'needs_secure_boot',
+    'hw_vif_multiqueue_enabled': 'is_hw_vif_multiqueue_enabled',
+    'hw_boot_menu': 'is_hw_boot_menu_enabled',
+    'auto_disk_config': 'has_auto_disk_config',
+}
 MEMBER_STATUS_CHOICES = ["accepted", "pending", "rejected", "all"]
 
-
 LOG = logging.getLogger(__name__)
 
 
@@ -89,6 +98,9 @@ def _format_image(image, human_readable=False):
         'virtual_size',
         'min_ram',
         'schema',
+        'is_hidden',
+        'hash_algo',
+        'hash_value',
     ]
 
     # TODO(gtema/anybody): actually it should be possible to drop this method,
@@ -154,8 +166,10 @@ def get_data_from_stdin():
         image = sys.stdin
         if hasattr(sys.stdin, 'buffer'):
             image = sys.stdin.buffer
-        if msvcrt:
-            msvcrt.setmode(sys.stdin.fileno(), os.O_BINARY)
+        if os.name == "nt":
+            import msvcrt
+
+            msvcrt.setmode(sys.stdin.fileno(), os.O_BINARY)  # type: ignore
 
         return image
     else:
@@ -359,8 +373,7 @@ class CreateImage(command.ShowOne):
             action="store_true",
             default=False,
             help=_(
-                "Show upload progress bar "
-                "(ignored if passing data via stdin)"
+                "Show upload progress bar (ignored if passing data via stdin)"
             ),
         )
         parser.add_argument(
@@ -401,8 +414,7 @@ class CreateImage(command.ShowOne):
             metavar="<tag>",
             action='append',
             help=_(
-                "Set a tag on this image "
-                "(repeat option to set multiple tags)"
+                "Set a tag on this image (repeat option to set multiple tags)"
             ),
         )
         parser.add_argument(
@@ -434,7 +446,7 @@ class CreateImage(command.ShowOne):
 
         # Build an attribute dict from the parsed args, only include
         # attributes that were actually set on the command line
-        kwargs = {'allow_duplicates': True}
+        kwargs: dict[str, ty.Any] = {'allow_duplicates': True}
         copy_attrs = (
             'name',
             'id',
@@ -539,7 +551,7 @@ class CreateImage(command.ShowOne):
             sign_cert_id = parsed_args.sign_cert_id
             signer = image_signer.ImageSigner()
             try:
-                pw = utils.get_password(
+                pw: str | None = utils.get_password(
                     self.app.stdin,
                     prompt=(
                         "Please enter private key password, leave "
@@ -550,12 +562,11 @@ class CreateImage(command.ShowOne):
 
                 if not pw or len(pw) < 1:
                     pw = None
-                else:
-                    # load_private_key() requires the password to be
-                    # passed as bytes
-                    pw = pw.encode()
 
-                signer.load_private_key(sign_key_path, password=pw)
+                signer.load_private_key(
+                    sign_key_path,
+                    password=pw.encode() if pw else None,
+                )
             except Exception:
                 msg = _(
                     "Error during sign operation: private key "
@@ -582,7 +593,7 @@ class CreateImage(command.ShowOne):
         return _format_image(image)
 
     def _take_action_volume(self, parsed_args):
-        volume_client = self.app.client_manager.volume
+        volume_client = self.app.client_manager.sdk_connection.volume
 
         unsupported_opts = {
             # 'name',  # 'name' is a positional argument and will always exist
@@ -611,14 +622,16 @@ class CreateImage(command.ShowOne):
                 )
                 # TODO(stephenfin): These should be an error in a future
                 # version
-                LOG.warning(msg % opt_name)
+                LOG.warning(msg, opt_name)
 
-        source_volume = utils.find_resource(
-            volume_client.volumes,
-            parsed_args.volume,
+        source_volume = volume_client.find_volume(
+            parsed_args.volume, ignore_missing=False
         )
-        kwargs = {}
-        if volume_client.api_version < api_versions.APIVersion('3.1'):
+        kwargs: dict[str, ty.Any] = {
+            'visibility': None,
+            'protected': None,
+        }
+        if not sdk_utils.supports_microversion(volume_client, '3.1'):
             if parsed_args.visibility or parsed_args.is_protected is not None:
                 msg = _(
                     '--os-volume-api-version 3.1 or greater is required '
@@ -627,20 +640,18 @@ class CreateImage(command.ShowOne):
                 )
                 raise exceptions.CommandError(msg)
         else:
-            kwargs.update(
-                visibility=parsed_args.visibility or 'private',
-                protected=parsed_args.is_protected or False,
-            )
+            kwargs['visibility'] = parsed_args.visibility or 'private'
+            kwargs['protected'] = parsed_args.is_protected or False
 
-        response, body = volume_client.volumes.upload_to_image(
+        response = volume_client.upload_volume_to_image(
             source_volume.id,
-            parsed_args.force,
             parsed_args.name,
-            parsed_args.container_format,
-            parsed_args.disk_format,
+            force=parsed_args.force,
+            disk_format=parsed_args.disk_format,
+            container_format=parsed_args.container_format,
             **kwargs,
         )
-        info = body['os-volume_upload_image']
+        info = copy.deepcopy(response)
         try:
             info['volume_type'] = info['volume_type']['name']
         except TypeError:
@@ -705,8 +716,7 @@ class DeleteImage(command.Command):
             except Exception as e:
                 result += 1
                 msg = _(
-                    "Failed to delete image with name or "
-                    "ID '%(image)s': %(e)s"
+                    "Failed to delete image with name or ID '%(image)s': %(e)s"
                 )
                 LOG.error(msg, {'image': image, 'e': e})
 
@@ -884,7 +894,7 @@ class ListImage(command.Lister):
         if parsed_args.is_hidden:
             kwargs['is_hidden'] = parsed_args.is_hidden
         if parsed_args.long:
-            columns = (
+            columns: tuple[str, ...] = (
                 'ID',
                 'Name',
                 'Disk Format',
@@ -895,9 +905,11 @@ class ListImage(command.Lister):
                 'visibility',
                 'is_protected',
                 'owner_id',
+                'hash_algo',
+                'hash_value',
                 'tags',
             )
-            column_headers = (
+            column_headers: tuple[str, ...] = (
                 'ID',
                 'Name',
                 'Disk Format',
@@ -908,6 +920,8 @@ class ListImage(command.Lister):
                 'Visibility',
                 'Protected',
                 'Project',
+                'Hash Algorithm',
+                'Hash Value',
                 'Tags',
             )
         else:
@@ -918,18 +932,19 @@ class ListImage(command.Lister):
         if 'limit' in kwargs:
             # Disable automatic pagination in SDK
             kwargs['paginated'] = False
-        data = list(image_client.images(**kwargs))
+
+        images = list(image_client.images(**kwargs))
 
         if parsed_args.property:
             for attr, value in parsed_args.property.items():
                 api_utils.simple_filter(
-                    data,
+                    images,
                     attr=attr,
                     value=value,
                     property_field='properties',
                 )
 
-        data = utils.sort_items(data, parsed_args.sort, str)
+        data = utils.sort_items(images, parsed_args.sort, str)
 
         return (
             column_headers,
@@ -959,7 +974,7 @@ class ListImageProjects(command.Lister):
 
     def take_action(self, parsed_args):
         image_client = self.app.client_manager.image
-        columns = ("Image ID", "Member ID", "Status")
+        columns: tuple[str, ...] = ("Image ID", "Member ID", "Status")
 
         image_id = image_client.find_image(
             parsed_args.image,
@@ -1058,6 +1073,16 @@ class SaveImage(command.Command):
 
     def get_parser(self, prog_name):
         parser = super().get_parser(prog_name)
+        parser.add_argument(
+            "--chunk-size",
+            type=int,
+            default=1024,
+            metavar="<chunk-size>",
+            help=_(
+                "Size in bytes to read from the wire and buffer at one "
+                "time (default: 1024)"
+            ),
+        )
         parser.add_argument(
             "--file",
             metavar="<filename>",
@@ -1082,7 +1107,12 @@ class SaveImage(command.Command):
         if output_file is None:
             output_file = getattr(sys.stdout, "buffer", sys.stdout)
 
-        image_client.download_image(image.id, stream=True, output=output_file)
+        image_client.download_image(
+            image.id,
+            stream=True,
+            output=output_file,
+            chunk_size=parsed_args.chunk_size,
+        )
 
 
 class SetImage(command.Command):
@@ -1153,8 +1183,7 @@ class SetImage(command.Command):
             default=None,
             action='append',
             help=_(
-                "Set a tag on this image "
-                "(repeat option to set multiple tags)"
+                "Set a tag on this image (repeat option to set multiple tags)"
             ),
         )
         parser.add_argument(
@@ -1364,7 +1393,10 @@ class SetImage(command.Command):
         if parsed_args.visibility is not None:
             kwargs['visibility'] = parsed_args.visibility
 
-        if parsed_args.project:
+        # Only set owner_id if --project is used WITHOUT membership flags
+        # When --project is used with --accept/--reject/--pending, it should
+        # only identify which member's status to update, not change ownership
+        if parsed_args.project and not parsed_args.membership:
             # We already did the project lookup above
             kwargs['owner_id'] = project_id
 
@@ -1457,7 +1489,6 @@ class UnsetImage(command.Command):
             ignore_missing=False,
         )
 
-        kwargs = {}
         tagret = 0
         propret = 0
         if parsed_args.tags:
@@ -1466,10 +1497,11 @@ class UnsetImage(command.Command):
                     image_client.remove_tag(image.id, k)
                 except Exception:
                     LOG.error(
-                        _("tag unset failed, '%s' is a " "nonexistent tag "), k
+                        _("tag unset failed, '%s' is a nonexistent tag "), k
                     )
                     tagret += 1
 
+        kwargs: dict[str, ty.Any] = {}
         if parsed_args.properties:
             for k in parsed_args.properties:
                 if k in image:
@@ -1484,6 +1516,11 @@ class UnsetImage(command.Command):
                     )
                     new_props.pop(k, None)
                     kwargs['properties'] = new_props
+                elif (
+                    k in IMAGE_ATTRIBUTES_CUSTOM_NAMES
+                    and IMAGE_ATTRIBUTES_CUSTOM_NAMES[k] in image
+                ):
+                    delattr(image, IMAGE_ATTRIBUTES_CUSTOM_NAMES[k])
                 else:
                     LOG.error(
                         _(
@@ -1519,7 +1556,7 @@ class UnsetImage(command.Command):
             raise exceptions.CommandError(msg)
         elif propret > 0:
             msg = _(
-                "Failed to unset %(propret)s of %(proptotal)s" " properties."
+                "Failed to unset %(propret)s of %(proptotal)s properties."
             ) % {'propret': propret, 'proptotal': proptotal}
             raise exceptions.CommandError(msg)
 
@@ -1551,8 +1588,7 @@ class StageImage(command.Command):
             action='store_true',
             default=False,
             help=_(
-                'Show upload progress bar '
-                '(ignored if passing data via stdin)'
+                'Show upload progress bar (ignored if passing data via stdin)'
             ),
         )
         parser.add_argument(
@@ -1583,7 +1619,7 @@ class StageImage(command.Command):
         else:
             fp = get_data_from_stdin()
 
-        kwargs = {}
+        kwargs: dict[str, ty.Any] = {}
 
         if parsed_args.progress and parsed_args.filename:
             # NOTE(stephenfin): we only show a progress bar if the user
@@ -1683,13 +1719,15 @@ class ImportImage(command.ShowOne):
         )
         stores_group.add_argument(
             '--all-stores',
+            action='store_true',
             help=_(
                 "Make image available to all stores "
                 "(either '--store' or '--all-stores' required with the "
                 "'copy-image' import method)"
             ),
         )
-        parser.add_argument(
+        allow_failure_group = parser.add_mutually_exclusive_group()
+        allow_failure_group.add_argument(
             '--allow-failure',
             action='store_true',
             dest='allow_failure',
@@ -1700,9 +1738,9 @@ class ImportImage(command.ShowOne):
                 'Only usable with --stores or --all-stores'
             ),
         )
-        parser.add_argument(
+        allow_failure_group.add_argument(
             '--disallow-failure',
-            action='store_true',
+            action='store_false',
             dest='allow_failure',
             default=True,
             help=_(
@@ -1751,6 +1789,12 @@ class ImportImage(command.ShowOne):
                     "'--method=web-download'"
                 )
                 raise exceptions.CommandError(msg)
+            _parsed = urllib.parse.urlparse(parsed_args.uri)
+            if not all({_parsed.scheme, _parsed.netloc}):
+                msg = _("'%(uri)s' is not a valid url")
+                raise exceptions.CommandError(
+                    msg % {'uri': parsed_args.uri},
+                )
         else:
             if parsed_args.uri:
                 msg = _(
@@ -1866,8 +1910,8 @@ class StoresInfo(command.Lister):
     def take_action(self, parsed_args):
         image_client = self.app.client_manager.image
         try:
-            columns = ("id", "description", "is_default")
-            column_headers = ("ID", "Description", "Default")
+            columns: tuple[str, ...] = ("id", "description", "is_default")
+            column_headers: tuple[str, ...] = ("ID", "Description", "Default")
             if parsed_args.detail:
                 columns += ("properties",)
                 column_headers += ("Properties",)
