@@ -12,8 +12,8 @@
 
 
 from osc_lib.cli import format_columns
-from osc_lib.command import command
 
+from openstackclient import command
 from openstackclient.i18n import _
 
 
