@@ -24,43 +24,37 @@ from openstackclient.volume.v2 import consistency_group
 
 
 class TestConsistencyGroup(volume_fakes.TestVolume):
-
     def setUp(self):
-        super(TestConsistencyGroup, self).setUp()
+        super().setUp()
 
         # Get a shortcut to the TransferManager Mock
-        self.consistencygroups_mock = (
-            self.app.client_manager.volume.consistencygroups)
+        self.consistencygroups_mock = self.volume_client.consistencygroups
         self.consistencygroups_mock.reset_mock()
 
-        self.cgsnapshots_mock = (
-            self.app.client_manager.volume.cgsnapshots)
+        self.cgsnapshots_mock = self.volume_client.cgsnapshots
         self.cgsnapshots_mock.reset_mock()
 
-        self.volumes_mock = (
-            self.app.client_manager.volume.volumes)
+        self.volumes_mock = self.volume_client.volumes
         self.volumes_mock.reset_mock()
 
-        self.types_mock = self.app.client_manager.volume.volume_types
+        self.types_mock = self.volume_client.volume_types
         self.types_mock.reset_mock()
 
 
 class TestConsistencyGroupAddVolume(TestConsistencyGroup):
-
-    _consistency_group = (
-        volume_fakes.FakeConsistencyGroup.create_one_consistency_group())
+    _consistency_group = volume_fakes.create_one_consistency_group()
 
     def setUp(self):
-        super(TestConsistencyGroupAddVolume, self).setUp()
+        super().setUp()
 
-        self.consistencygroups_mock.get.return_value = (
-            self._consistency_group)
+        self.consistencygroups_mock.get.return_value = self._consistency_group
         # Get the command object to test
-        self.cmd = \
-            consistency_group.AddVolumeToConsistencyGroup(self.app, None)
+        self.cmd = consistency_group.AddVolumeToConsistencyGroup(
+            self.app, None
+        )
 
     def test_add_one_volume_to_consistency_group(self):
-        volume = volume_fakes.FakeVolume.create_one_volume()
+        volume = volume_fakes.create_one_volume()
         self.volumes_mock.get.return_value = volume
         arglist = [
             self._consistency_group.id,
@@ -79,14 +73,13 @@ class TestConsistencyGroupAddVolume(TestConsistencyGroup):
             'add_volumes': volume.id,
         }
         self.consistencygroups_mock.update.assert_called_once_with(
-            self._consistency_group.id,
-            **kwargs
+            self._consistency_group.id, **kwargs
         )
         self.assertIsNone(result)
 
     def test_add_multiple_volumes_to_consistency_group(self):
-        volumes = volume_fakes.FakeVolume.create_volumes(count=2)
-        self.volumes_mock.get = volume_fakes.FakeVolume.get_volumes(volumes)
+        volumes = volume_fakes.create_volumes(count=2)
+        self.volumes_mock.get = volume_fakes.get_volumes(volumes)
         arglist = [
             self._consistency_group.id,
             volumes[0].id,
@@ -105,15 +98,16 @@ class TestConsistencyGroupAddVolume(TestConsistencyGroup):
             'add_volumes': volumes[0].id + ',' + volumes[1].id,
         }
         self.consistencygroups_mock.update.assert_called_once_with(
-            self._consistency_group.id,
-            **kwargs
+            self._consistency_group.id, **kwargs
         )
         self.assertIsNone(result)
 
     @mock.patch.object(consistency_group.LOG, 'error')
     def test_add_multiple_volumes_to_consistency_group_with_exception(
-            self, mock_error):
-        volume = volume_fakes.FakeVolume.create_one_volume()
+        self,
+        mock_error,
+    ):
+        volume = volume_fakes.create_one_volume()
         arglist = [
             self._consistency_group.id,
             volume.id,
@@ -126,20 +120,25 @@ class TestConsistencyGroupAddVolume(TestConsistencyGroup):
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        find_mock_result = [volume,
-                            exceptions.CommandError,
-                            self._consistency_group]
-        with mock.patch.object(utils, 'find_resource',
-                               side_effect=find_mock_result) as find_mock:
+        find_mock_result = [
+            volume,
+            exceptions.CommandError,
+            self._consistency_group,
+        ]
+        with mock.patch.object(
+            utils, 'find_resource', side_effect=find_mock_result
+        ) as find_mock:
             result = self.cmd.take_action(parsed_args)
-            mock_error.assert_called_with("1 of 2 volumes failed to add.")
+            mock_error.assert_called_with(
+                '%(result)s of %(total)s volumes failed to add.',
+                {'result': 1, 'total': 2},
+            )
             self.assertIsNone(result)
-            find_mock.assert_any_call(self.consistencygroups_mock,
-                                      self._consistency_group.id)
-            find_mock.assert_any_call(self.volumes_mock,
-                                      volume.id)
-            find_mock.assert_any_call(self.volumes_mock,
-                                      'unexist_volume')
+            find_mock.assert_any_call(
+                self.consistencygroups_mock, self._consistency_group.id
+            )
+            find_mock.assert_any_call(self.volumes_mock, volume.id)
+            find_mock.assert_any_call(self.volumes_mock, 'unexist_volume')
             self.assertEqual(3, find_mock.call_count)
             self.consistencygroups_mock.update.assert_called_once_with(
                 self._consistency_group.id, add_volumes=volume.id
@@ -147,14 +146,10 @@ class TestConsistencyGroupAddVolume(TestConsistencyGroup):
 
 
 class TestConsistencyGroupCreate(TestConsistencyGroup):
-
-    volume_type = volume_fakes.FakeType.create_one_type()
-    new_consistency_group = (
-        volume_fakes.FakeConsistencyGroup.create_one_consistency_group())
+    volume_type = volume_fakes.create_one_volume_type()
+    new_consistency_group = volume_fakes.create_one_consistency_group()
     consistency_group_snapshot = (
-        volume_fakes.
-        FakeConsistencyGroupSnapshot.
-        create_one_consistency_group_snapshot()
+        volume_fakes.create_one_consistency_group_snapshot()
     )
 
     columns = (
@@ -177,24 +172,30 @@ class TestConsistencyGroupCreate(TestConsistencyGroup):
     )
 
     def setUp(self):
-        super(TestConsistencyGroupCreate, self).setUp()
+        super().setUp()
         self.consistencygroups_mock.create.return_value = (
-            self.new_consistency_group)
+            self.new_consistency_group
+        )
         self.consistencygroups_mock.create_from_src.return_value = (
-            self.new_consistency_group)
+            self.new_consistency_group
+        )
         self.consistencygroups_mock.get.return_value = (
-            self.new_consistency_group)
+            self.new_consistency_group
+        )
         self.types_mock.get.return_value = self.volume_type
         self.cgsnapshots_mock.get.return_value = (
-            self.consistency_group_snapshot)
+            self.consistency_group_snapshot
+        )
 
         # Get the command object to test
         self.cmd = consistency_group.CreateConsistencyGroup(self.app, None)
 
     def test_consistency_group_create(self):
         arglist = [
-            '--volume-type', self.volume_type.id,
-            '--description', self.new_consistency_group.description,
+            '--volume-type',
+            self.volume_type.id,
+            '--description',
+            self.new_consistency_group.description,
             '--availability-zone',
             self.new_consistency_group.availability_zone,
             self.new_consistency_group.name,
@@ -202,16 +203,17 @@ class TestConsistencyGroupCreate(TestConsistencyGroup):
         verifylist = [
             ('volume_type', self.volume_type.id),
             ('description', self.new_consistency_group.description),
-            ('availability_zone',
-             self.new_consistency_group.availability_zone),
+            (
+                'availability_zone',
+                self.new_consistency_group.availability_zone,
+            ),
             ('name', self.new_consistency_group.name),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.types_mock.get.assert_called_once_with(
-            self.volume_type.id)
+        self.types_mock.get.assert_called_once_with(self.volume_type.id)
         self.consistencygroups_mock.get.assert_not_called()
         self.consistencygroups_mock.create.assert_called_once_with(
             self.volume_type.id,
@@ -225,23 +227,26 @@ class TestConsistencyGroupCreate(TestConsistencyGroup):
 
     def test_consistency_group_create_without_name(self):
         arglist = [
-            '--volume-type', self.volume_type.id,
-            '--description', self.new_consistency_group.description,
+            '--volume-type',
+            self.volume_type.id,
+            '--description',
+            self.new_consistency_group.description,
             '--availability-zone',
             self.new_consistency_group.availability_zone,
         ]
         verifylist = [
             ('volume_type', self.volume_type.id),
             ('description', self.new_consistency_group.description),
-            ('availability_zone',
-             self.new_consistency_group.availability_zone),
+            (
+                'availability_zone',
+                self.new_consistency_group.availability_zone,
+            ),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.types_mock.get.assert_called_once_with(
-            self.volume_type.id)
+        self.types_mock.get.assert_called_once_with(self.volume_type.id)
         self.consistencygroups_mock.get.assert_not_called()
         self.consistencygroups_mock.create.assert_called_once_with(
             self.volume_type.id,
@@ -251,16 +256,18 @@ class TestConsistencyGroupCreate(TestConsistencyGroup):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_consistency_group_create_from_source(self):
         arglist = [
-            '--consistency-group-source', self.new_consistency_group.id,
-            '--description', self.new_consistency_group.description,
+            '--consistency-group-source',
+            self.new_consistency_group.id,
+            '--description',
+            self.new_consistency_group.description,
             self.new_consistency_group.name,
         ]
         verifylist = [
-            ('consistency_group_source', self.new_consistency_group.id),
+            ('source', self.new_consistency_group.id),
             ('description', self.new_consistency_group.description),
             ('name', self.new_consistency_group.name),
         ]
@@ -270,7 +277,8 @@ class TestConsistencyGroupCreate(TestConsistencyGroup):
 
         self.types_mock.get.assert_not_called()
         self.consistencygroups_mock.get.assert_called_once_with(
-            self.new_consistency_group.id)
+            self.new_consistency_group.id
+        )
         self.consistencygroups_mock.create_from_src.assert_called_with(
             None,
             self.new_consistency_group.id,
@@ -279,16 +287,18 @@ class TestConsistencyGroupCreate(TestConsistencyGroup):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_consistency_group_create_from_snapshot(self):
         arglist = [
-            '--consistency-group-snapshot', self.consistency_group_snapshot.id,
-            '--description', self.new_consistency_group.description,
+            '--consistency-group-snapshot',
+            self.consistency_group_snapshot.id,
+            '--description',
+            self.new_consistency_group.description,
             self.new_consistency_group.name,
         ]
         verifylist = [
-            ('consistency_group_snapshot', self.consistency_group_snapshot.id),
+            ('snapshot', self.consistency_group_snapshot.id),
             ('description', self.new_consistency_group.description),
             ('name', self.new_consistency_group.name),
         ]
@@ -298,7 +308,8 @@ class TestConsistencyGroupCreate(TestConsistencyGroup):
 
         self.types_mock.get.assert_not_called()
         self.cgsnapshots_mock.get.assert_called_once_with(
-            self.consistency_group_snapshot.id)
+            self.consistency_group_snapshot.id
+        )
         self.consistencygroups_mock.create_from_src.assert_called_with(
             self.consistency_group_snapshot.id,
             None,
@@ -307,37 +318,33 @@ class TestConsistencyGroupCreate(TestConsistencyGroup):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
 
 class TestConsistencyGroupDelete(TestConsistencyGroup):
-
-    consistency_groups =\
-        volume_fakes.FakeConsistencyGroup.create_consistency_groups(count=2)
+    consistency_groups = volume_fakes.create_consistency_groups(count=2)
 
     def setUp(self):
-        super(TestConsistencyGroupDelete, self).setUp()
+        super().setUp()
 
-        self.consistencygroups_mock.get = volume_fakes.FakeConsistencyGroup.\
-            get_consistency_groups(self.consistency_groups)
+        self.consistencygroups_mock.get = volume_fakes.get_consistency_groups(
+            self.consistency_groups,
+        )
         self.consistencygroups_mock.delete.return_value = None
 
         # Get the command object to mock
         self.cmd = consistency_group.DeleteConsistencyGroup(self.app, None)
 
     def test_consistency_group_delete(self):
-        arglist = [
-            self.consistency_groups[0].id
-        ]
-        verifylist = [
-            ("consistency_groups", [self.consistency_groups[0].id])
-        ]
+        arglist = [self.consistency_groups[0].id]
+        verifylist = [("consistency_groups", [self.consistency_groups[0].id])]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         result = self.cmd.take_action(parsed_args)
 
         self.consistencygroups_mock.delete.assert_called_with(
-            self.consistency_groups[0].id, False)
+            self.consistency_groups[0].id, False
+        )
         self.assertIsNone(result)
 
     def test_consistency_group_delete_with_force(self):
@@ -347,14 +354,15 @@ class TestConsistencyGroupDelete(TestConsistencyGroup):
         ]
         verifylist = [
             ('force', True),
-            ("consistency_groups", [self.consistency_groups[0].id])
+            ("consistency_groups", [self.consistency_groups[0].id]),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         result = self.cmd.take_action(parsed_args)
 
         self.consistencygroups_mock.delete.assert_called_with(
-            self.consistency_groups[0].id, True)
+            self.consistency_groups[0].id, True
+        )
         self.assertIsNone(result)
 
     def test_delete_multiple_consistency_groups(self):
@@ -385,21 +393,27 @@ class TestConsistencyGroupDelete(TestConsistencyGroup):
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        find_mock_result = [self.consistency_groups[0],
-                            exceptions.CommandError]
-        with mock.patch.object(utils, 'find_resource',
-                               side_effect=find_mock_result) as find_mock:
+        find_mock_result = [
+            self.consistency_groups[0],
+            exceptions.CommandError,
+        ]
+        with mock.patch.object(
+            utils, 'find_resource', side_effect=find_mock_result
+        ) as find_mock:
             try:
                 self.cmd.take_action(parsed_args)
                 self.fail('CommandError should be raised.')
             except exceptions.CommandError as e:
-                self.assertEqual('1 of 2 consistency groups failed to delete.',
-                                 str(e))
+                self.assertEqual(
+                    '1 of 2 consistency groups failed to delete.', str(e)
+                )
 
-            find_mock.assert_any_call(self.consistencygroups_mock,
-                                      self.consistency_groups[0].id)
-            find_mock.assert_any_call(self.consistencygroups_mock,
-                                      'unexist_consistency_group')
+            find_mock.assert_any_call(
+                self.consistencygroups_mock, self.consistency_groups[0].id
+            )
+            find_mock.assert_any_call(
+                self.consistencygroups_mock, 'unexist_consistency_group'
+            )
 
             self.assertEqual(2, find_mock.call_count)
             self.consistencygroups_mock.delete.assert_called_once_with(
@@ -408,9 +422,7 @@ class TestConsistencyGroupDelete(TestConsistencyGroup):
 
 
 class TestConsistencyGroupList(TestConsistencyGroup):
-
-    consistency_groups = (
-        volume_fakes.FakeConsistencyGroup.create_consistency_groups(count=2))
+    consistency_groups = volume_fakes.create_consistency_groups(count=2)
 
     columns = [
         'ID',
@@ -427,24 +439,28 @@ class TestConsistencyGroupList(TestConsistencyGroup):
     ]
     data = []
     for c in consistency_groups:
-        data.append((
-            c.id,
-            c.status,
-            c.name,
-        ))
+        data.append(
+            (
+                c.id,
+                c.status,
+                c.name,
+            )
+        )
     data_long = []
     for c in consistency_groups:
-        data_long.append((
-            c.id,
-            c.status,
-            c.availability_zone,
-            c.name,
-            c.description,
-            format_columns.ListColumn(c.volume_types)
-        ))
+        data_long.append(
+            (
+                c.id,
+                c.status,
+                c.availability_zone,
+                c.name,
+                c.description,
+                format_columns.ListColumn(c.volume_types),
+            )
+        )
 
     def setUp(self):
-        super(TestConsistencyGroupList, self).setUp()
+        super().setUp()
 
         self.consistencygroups_mock.list.return_value = self.consistency_groups
         # Get the command to test
@@ -461,14 +477,13 @@ class TestConsistencyGroupList(TestConsistencyGroup):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.consistencygroups_mock.list.assert_called_once_with(
-            detailed=True, search_opts={'all_tenants': False})
+            detailed=True, search_opts={'all_tenants': False}
+        )
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_consistency_group_list_with_all_project(self):
-        arglist = [
-            "--all-projects"
-        ]
+        arglist = ["--all-projects"]
         verifylist = [
             ("all_projects", True),
             ("long", False),
@@ -478,9 +493,10 @@ class TestConsistencyGroupList(TestConsistencyGroup):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.consistencygroups_mock.list.assert_called_once_with(
-            detailed=True, search_opts={'all_tenants': True})
+            detailed=True, search_opts={'all_tenants': True}
+        )
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_consistency_group_list_with_long(self):
         arglist = [
@@ -495,27 +511,26 @@ class TestConsistencyGroupList(TestConsistencyGroup):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.consistencygroups_mock.list.assert_called_once_with(
-            detailed=True, search_opts={'all_tenants': False})
+            detailed=True, search_opts={'all_tenants': False}
+        )
         self.assertEqual(self.columns_long, columns)
-        self.assertListItemEqual(self.data_long, list(data))
+        self.assertCountEqual(self.data_long, list(data))
 
 
 class TestConsistencyGroupRemoveVolume(TestConsistencyGroup):
-
-    _consistency_group = (
-        volume_fakes.FakeConsistencyGroup.create_one_consistency_group())
+    _consistency_group = volume_fakes.create_one_consistency_group()
 
     def setUp(self):
-        super(TestConsistencyGroupRemoveVolume, self).setUp()
+        super().setUp()
 
-        self.consistencygroups_mock.get.return_value = (
-            self._consistency_group)
+        self.consistencygroups_mock.get.return_value = self._consistency_group
         # Get the command object to test
-        self.cmd = \
-            consistency_group.RemoveVolumeFromConsistencyGroup(self.app, None)
+        self.cmd = consistency_group.RemoveVolumeFromConsistencyGroup(
+            self.app, None
+        )
 
     def test_remove_one_volume_from_consistency_group(self):
-        volume = volume_fakes.FakeVolume.create_one_volume()
+        volume = volume_fakes.create_one_volume()
         self.volumes_mock.get.return_value = volume
         arglist = [
             self._consistency_group.id,
@@ -534,14 +549,13 @@ class TestConsistencyGroupRemoveVolume(TestConsistencyGroup):
             'remove_volumes': volume.id,
         }
         self.consistencygroups_mock.update.assert_called_once_with(
-            self._consistency_group.id,
-            **kwargs
+            self._consistency_group.id, **kwargs
         )
         self.assertIsNone(result)
 
     def test_remove_multi_volumes_from_consistency_group(self):
-        volumes = volume_fakes.FakeVolume.create_volumes(count=2)
-        self.volumes_mock.get = volume_fakes.FakeVolume.get_volumes(volumes)
+        volumes = volume_fakes.create_volumes(count=2)
+        self.volumes_mock.get = volume_fakes.get_volumes(volumes)
         arglist = [
             self._consistency_group.id,
             volumes[0].id,
@@ -560,15 +574,16 @@ class TestConsistencyGroupRemoveVolume(TestConsistencyGroup):
             'remove_volumes': volumes[0].id + ',' + volumes[1].id,
         }
         self.consistencygroups_mock.update.assert_called_once_with(
-            self._consistency_group.id,
-            **kwargs
+            self._consistency_group.id, **kwargs
         )
         self.assertIsNone(result)
 
     @mock.patch.object(consistency_group.LOG, 'error')
     def test_remove_multiple_volumes_from_consistency_group_with_exception(
-            self, mock_error):
-        volume = volume_fakes.FakeVolume.create_one_volume()
+        self,
+        mock_error,
+    ):
+        volume = volume_fakes.create_one_volume()
         arglist = [
             self._consistency_group.id,
             volume.id,
@@ -581,20 +596,25 @@ class TestConsistencyGroupRemoveVolume(TestConsistencyGroup):
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        find_mock_result = [volume,
-                            exceptions.CommandError,
-                            self._consistency_group]
-        with mock.patch.object(utils, 'find_resource',
-                               side_effect=find_mock_result) as find_mock:
+        find_mock_result = [
+            volume,
+            exceptions.CommandError,
+            self._consistency_group,
+        ]
+        with mock.patch.object(
+            utils, 'find_resource', side_effect=find_mock_result
+        ) as find_mock:
             result = self.cmd.take_action(parsed_args)
-            mock_error.assert_called_with("1 of 2 volumes failed to remove.")
+            mock_error.assert_called_with(
+                '%(result)s of %(total)s volumes failed to remove.',
+                {'result': 1, 'total': 2},
+            )
             self.assertIsNone(result)
-            find_mock.assert_any_call(self.consistencygroups_mock,
-                                      self._consistency_group.id)
-            find_mock.assert_any_call(self.volumes_mock,
-                                      volume.id)
-            find_mock.assert_any_call(self.volumes_mock,
-                                      'unexist_volume')
+            find_mock.assert_any_call(
+                self.consistencygroups_mock, self._consistency_group.id
+            )
+            find_mock.assert_any_call(self.volumes_mock, volume.id)
+            find_mock.assert_any_call(self.volumes_mock, 'unexist_volume')
             self.assertEqual(3, find_mock.call_count)
             self.consistencygroups_mock.update.assert_called_once_with(
                 self._consistency_group.id, remove_volumes=volume.id
@@ -602,22 +622,20 @@ class TestConsistencyGroupRemoveVolume(TestConsistencyGroup):
 
 
 class TestConsistencyGroupSet(TestConsistencyGroup):
-
-    consistency_group = (
-        volume_fakes.FakeConsistencyGroup.create_one_consistency_group())
+    consistency_group = volume_fakes.create_one_consistency_group()
 
     def setUp(self):
-        super(TestConsistencyGroupSet, self).setUp()
+        super().setUp()
 
-        self.consistencygroups_mock.get.return_value = (
-            self.consistency_group)
+        self.consistencygroups_mock.get.return_value = self.consistency_group
         # Get the command object to test
         self.cmd = consistency_group.SetConsistencyGroup(self.app, None)
 
     def test_consistency_group_set_name(self):
         new_name = 'new_name'
         arglist = [
-            '--name', new_name,
+            '--name',
+            new_name,
             self.consistency_group.id,
         ]
         verifylist = [
@@ -634,15 +652,15 @@ class TestConsistencyGroupSet(TestConsistencyGroup):
             'name': new_name,
         }
         self.consistencygroups_mock.update.assert_called_once_with(
-            self.consistency_group.id,
-            **kwargs
+            self.consistency_group.id, **kwargs
         )
         self.assertIsNone(result)
 
     def test_consistency_group_set_description(self):
         new_description = 'new_description'
         arglist = [
-            '--description', new_description,
+            '--description',
+            new_description,
             self.consistency_group.id,
         ]
         verifylist = [
@@ -659,8 +677,7 @@ class TestConsistencyGroupSet(TestConsistencyGroup):
             'description': new_description,
         }
         self.consistencygroups_mock.update.assert_called_once_with(
-            self.consistency_group.id,
-            **kwargs
+            self.consistency_group.id, **kwargs
         )
         self.assertIsNone(result)
 
@@ -677,10 +694,9 @@ class TestConsistencyGroupShow(TestConsistencyGroup):
     )
 
     def setUp(self):
-        super(TestConsistencyGroupShow, self).setUp()
+        super().setUp()
 
-        self.consistency_group = (
-            volume_fakes.FakeConsistencyGroup.create_one_consistency_group())
+        self.consistency_group = volume_fakes.create_one_consistency_group()
         self.data = (
             self.consistency_group.availability_zone,
             self.consistency_group.created_at,
@@ -694,15 +710,12 @@ class TestConsistencyGroupShow(TestConsistencyGroup):
         self.cmd = consistency_group.ShowConsistencyGroup(self.app, None)
 
     def test_consistency_group_show(self):
-        arglist = [
-            self.consistency_group.id
-        ]
-        verifylist = [
-            ("consistency_group", self.consistency_group.id)
-        ]
+        arglist = [self.consistency_group.id]
+        verifylist = [("consistency_group", self.consistency_group.id)]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
         self.consistencygroups_mock.get.assert_called_once_with(
-            self.consistency_group.id)
+            self.consistency_group.id
+        )
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
