@@ -37,6 +37,7 @@ class TestVolumeCreate(volume_fakes.TestVolume):
     columns = (
         'attachments',
         'availability_zone',
+        'backup_id',
         'bootable',
         'cluster_name',
         'consistencygroup_id',
@@ -78,6 +79,7 @@ class TestVolumeCreate(volume_fakes.TestVolume):
         self.datalist = (
             self.volume.attachments,
             self.volume.availability_zone,
+            self.volume.backup_id,
             self.volume.is_bootable,
             self.volume.cluster_name,
             self.volume.consistency_group_id,
@@ -910,7 +912,7 @@ class TestVolumeDelete(volume_fakes.TestVolume):
         arglist = [self.volumes[0].id]
         verifylist = [
             ("force", False),
-            ("purge", False),
+            ("cascade", False),
             ("volumes", [self.volumes[0].id]),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -929,7 +931,7 @@ class TestVolumeDelete(volume_fakes.TestVolume):
         arglist = [v.id for v in self.volumes]
         verifylist = [
             ('force', False),
-            ('purge', False),
+            ('cascade', False),
             ('volumes', arglist),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -956,7 +958,7 @@ class TestVolumeDelete(volume_fakes.TestVolume):
         ]
         verifylist = [
             ('force', False),
-            ('purge', False),
+            ('cascade', False),
             ('volumes', [self.volumes[0].id, 'unexist_volume']),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -987,7 +989,29 @@ class TestVolumeDelete(volume_fakes.TestVolume):
         ]
         verifylist = [
             ('force', False),
-            ('purge', True),
+            ('cascade', True),
+            ('volumes', [self.volumes[0].id]),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        result = self.cmd.take_action(parsed_args)
+        self.assertIsNone(result)
+
+        self.volume_sdk_client.find_volume.assert_called_once_with(
+            self.volumes[0].id, ignore_missing=False
+        )
+        self.volume_sdk_client.delete_volume.assert_called_once_with(
+            self.volumes[0].id, cascade=True, force=False
+        )
+
+    def test_volume_delete_with_cascade(self):
+        arglist = [
+            '--cascade',
+            self.volumes[0].id,
+        ]
+        verifylist = [
+            ('force', False),
+            ('cascade', True),
             ('volumes', [self.volumes[0].id]),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -1009,7 +1033,7 @@ class TestVolumeDelete(volume_fakes.TestVolume):
         ]
         verifylist = [
             ('force', True),
-            ('purge', False),
+            ('cascade', False),
             ('volumes', [self.volumes[0].id]),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -1029,7 +1053,7 @@ class TestVolumeDelete(volume_fakes.TestVolume):
         verifylist = [
             ("remote", True),
             ("force", False),
-            ("purge", False),
+            ("cascade", False),
             ("volumes", [self.volumes[0].id]),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -1050,7 +1074,7 @@ class TestVolumeDelete(volume_fakes.TestVolume):
         verifylist = [
             ('remote', True),
             ('force', False),
-            ('purge', False),
+            ('cascade', False),
             ('volumes', arglist[1:]),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -1075,7 +1099,6 @@ class TestVolumeDelete(volume_fakes.TestVolume):
         verifylist = [
             ('remote', True),
             ('force', False),
-            ('purge', True),
             ('volumes', [self.volumes[0].id]),
         ]
 
@@ -1084,7 +1107,7 @@ class TestVolumeDelete(volume_fakes.TestVolume):
             exceptions.CommandError, self.cmd.take_action, parsed_args
         )
         self.assertIn(
-            "The --force and --purge options are not supported with the "
+            "The --force and --cascade options are not supported with the "
             "--remote parameter.",
             str(exc),
         )
@@ -1102,7 +1125,7 @@ class TestVolumeDelete(volume_fakes.TestVolume):
         verifylist = [
             ('remote', True),
             ('force', True),
-            ('purge', False),
+            ('cascade', False),
             ('volumes', [self.volumes[0].id]),
         ]
 
@@ -1111,7 +1134,7 @@ class TestVolumeDelete(volume_fakes.TestVolume):
             exceptions.CommandError, self.cmd.take_action, parsed_args
         )
         self.assertIn(
-            "The --force and --purge options are not supported with the "
+            "The --force and --cascade options are not supported with the "
             "--remote parameter.",
             str(exc),
         )
@@ -1996,7 +2019,8 @@ class TestVolumeSet(volume_fakes.TestVolume):
         result = self.cmd.take_action(parsed_args)
         self.volumes_mock.retype.assert_not_called()
         mock_warning.assert_called_with(
-            "'--retype-policy' option will not work without '--type' option"
+            "'%s' option will not work without '--type' option",
+            '--retype-policy',
         )
         self.assertIsNone(result)
 
@@ -2011,6 +2035,7 @@ class TestVolumeShow(volume_fakes.TestVolume):
         self.columns = (
             'attachments',
             'availability_zone',
+            'backup_id',
             'bootable',
             'cluster_name',
             'consistencygroup_id',
@@ -2045,6 +2070,7 @@ class TestVolumeShow(volume_fakes.TestVolume):
         self.data = (
             self.volume.attachments,
             self.volume.availability_zone,
+            self.volume.backup_id,
             self.volume.is_bootable,
             self.volume.cluster_name,
             self.volume.consistency_group_id,
